pub fn failure_events(
projection: &SessionProjection,
error_code: &str,
) -> Vec<Event>Expand description
Events that close an interrupted Run as failed with error_code.
pub fn failure_events(
projection: &SessionProjection,
error_code: &str,
) -> Vec<Event>Events that close an interrupted Run as failed with error_code.