pub trait EventWriter: Send + Sync {
// Required methods
fn append<'life0, 'async_trait>(
&'life0 self,
events: Vec<Event>,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn load_after<'life0, 'async_trait>(
&'life0 self,
seq: u64,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Fenced append/read access to the Session log for one Run.
Required Methods
Sourcefn append<'life0, 'async_trait>(
&'life0 self,
events: Vec<Event>,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn append<'life0, 'async_trait>(
&'life0 self,
events: Vec<Event>,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Append events atomically and return them with assigned sequences.
Sourcefn load_after<'life0, 'async_trait>(
&'life0 self,
seq: u64,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn load_after<'life0, 'async_trait>(
&'life0 self,
seq: u64,
) -> Pin<Box<dyn Future<Output = Result<Vec<SessionEvent>, RuntimeError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Events committed after seq.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".